@@ -608,7 +608,7 @@ int TransferItem::preferredConnections() const {
 }
 
 void TransferItem::setPreferredConnections(int pref, bool overrideGlobalSetting) {
-    if ((pref != this->preferredConnections()) && (pref > 0) && (pref < this->maximumConnections())) {
+    if ((pref != this->preferredConnections()) && (pref > 0) && (pref <= this->maximumConnections())) {
         m_preferredConnections = pref;
         emit preferredConnectionsChanged(pref);
 
