@@ -231,7 +231,7 @@ void UrlGrabber::addYouTubeDecryptionFunctionToCache() {
     }
 
     QString response(reply->readAll());
-    QRegExp re("\\.sig\\|\\|\\w+(?=\\()");
+    QRegExp re("\\.sig\\|\\|[\\w\\$]+(?=\\()");
 
     if (re.indexIn(response) != -1) {
         QString funcName = re.cap().section("||", -1);
