@@ -1,12 +1,12 @@
 #include "dailymotionauthdialog.h"
-#include "../base/session.h"
+#include "../base/dailymotion.h"
+#include "../base/notifications.h"
 #include "webview.h"
 #include <QProgressBar>
 #include <QGridLayout>
 
-DailymotionAuthDialog::DailymotionAuthDialog(Session *session, const QString &accountName, QWidget *parent) :
+DailymotionAuthDialog::DailymotionAuthDialog(const QString &accountName, QWidget *parent) :
     AbstractDialog(parent),
-    m_session(session),
     m_name(accountName),
     m_webView(new WebView(this)),
     m_progressBar(new QProgressBar(this)),
@@ -16,7 +16,7 @@ DailymotionAuthDialog::DailymotionAuthDialog(Session *session, const QString &ac
 
     m_grid->addWidget(m_webView, 0, 0);
     m_grid->addWidget(m_progressBar, 1, 0);
-    m_webView->setUrl(m_session->dailymotion()->authUrl());
+    m_webView->setUrl(Dailymotion::instance()->authUrl());
     m_webView->enableSelectionSuppressor();
     m_progressBar->setTextVisible(false);
 
@@ -30,11 +30,11 @@ DailymotionAuthDialog::DailymotionAuthDialog(Session *session, const QString &ac
 
 void DailymotionAuthDialog::checkUrlForCode(const QUrl &url) {
     if (url.hasQueryItem("code")) {
-        m_session->dailymotion()->signIn(m_name, url);
+        Dailymotion::instance()->signIn(m_name, url);
         this->accept();
     }
     else if (url.queryItemValue("reason") == "access_denied") {
-        m_session->onInfo(tr("You have denied access to your Dailymotion account"));
+        Notifications::showInfo(tr("You have denied access to your Dailymotion account"));
         this->reject();
     }
 }
