@@ -4,12 +4,13 @@
 #include "../base/dailymotionuserlistmodel.h"
 #include "listview.h"
 #include <QLabel>
+#include <QMaemo5Style>
 
 DailymotionUserListWindow::DailymotionUserListWindow(QWidget *parent) :
     StackedWindow(parent),
     m_model(new DailymotionUserListModel(this)),
     m_listView(new ListView(this)),
-    m_noResultsLabel(new QLabel(QString("<p style='color:#4d4d4d;font-size:40px;'><center><b>%1</b></center></p>").arg(tr("No channels found")), this))
+    m_noResultsLabel(new QLabel(QString("<p style='color:%1;font-size:40px;'><center><b>%2</b></center></p>").arg(QMaemo5Style::standardColor("SecondaryTextColor").name()).arg(tr("No channels found")), this))
 {
     this->setCentralWidget(m_listView);
 
