@@ -3,7 +3,6 @@
 
 #include "abstractdialog.h"
 
-class Settings;
 class NetworkProxyTypeSelector;
 class QCheckBox;
 class QLineEdit;
@@ -16,7 +15,7 @@ class NetworkProxyDialog : public AbstractDialog
     Q_OBJECT
 
 public:
-    explicit NetworkProxyDialog(Settings *settings, QWidget *parent = 0);
+    explicit NetworkProxyDialog(QWidget *parent = 0);
 
 private:
     void setLandscapeLayout();
@@ -28,7 +27,6 @@ private slots:
     void onProxyCheckboxToggled(bool checked);
     
 private:
-    Settings *m_settings;
     QCheckBox *m_proxyCheckbox;
     QWidget *m_proxyWidget;
     NetworkProxyTypeSelector *m_proxyTypeSelector;
