@@ -15,12 +15,15 @@
 #include "../base/sharing.h"
 #include "../base/transfermanager.h"
 #include "../base/playbacklistmodel.h"
+#include "../base/utils.h"
 #include "thumbnaillabel.h"
+#include "resourceloader.h"
 #include <QAction>
 #include <QLabel>
 #include <QPushButton>
 #include <QScrollArea>
 #include <QGridLayout>
+#include <QDesktopServices>
 #include <QMaemo5Style>
 
 YouTubeVideoDescriptionTab::YouTubeVideoDescriptionTab(QSharedPointer<VideoItem> video, QWidget *parent) :
@@ -43,7 +46,7 @@ YouTubeVideoDescriptionTab::YouTubeVideoDescriptionTab(QSharedPointer<VideoItem>
     m_likesLabel(new QLabel(QString::number(m_video.data()->likes()), this)),
     m_dislikesLabel(new QLabel(QString::number(m_video.data()->dislikes()), this)),
     m_viewsLabel(new QLabel(QString("%1   <font color='%2'>%3</font>").arg(tr("Views")).arg(QMaemo5Style::standardColor("SecondaryTextColor").name()).arg(m_video.data()->viewCount()), this)),
-    m_descriptionLabel(new QLabel(QString("%1<br><font color='%2'>%3</font>").arg(tr("Description")).arg(QMaemo5Style::standardColor("SecondaryTextColor").name()).arg(m_video.data()->description().isEmpty() ? tr("No description") : m_video.data()->description()), this)),
+    m_descriptionLabel(new QLabel(QString("%1<br><font color='%2'>%3</font>").arg(tr("Description")).arg(QMaemo5Style::standardColor("SecondaryTextColor").name()).arg(m_video.data()->description().isEmpty() ? tr("No description") : Utils::toRichText(m_video.data()->description())), this)),
     m_scrollArea(new QScrollArea(this)),
     m_grid(new QGridLayout(this))
 {
@@ -93,6 +96,7 @@ YouTubeVideoDescriptionTab::YouTubeVideoDescriptionTab(QSharedPointer<VideoItem>
     this->connect(m_dislikeButton, SIGNAL(clicked()), this, SLOT(dislikeVideo()));
     this->connect(m_thumbnail, SIGNAL(clicked()), this, SLOT(playVideo()));
     this->connect(m_avatar, SIGNAL(clicked()), this, SLOT(showUserChannel()));
+    this->connect(m_descriptionLabel, SIGNAL(linkActivated(QString)), this, SLOT(parseActivatedLink(QString)));
     this->connect(m_video.data(), SIGNAL(likesChanged(int)), this, SLOT(onLikesChanged(int)));
     this->connect(m_video.data(), SIGNAL(dislikesChanged(int)), this, SLOT(onDislikesChanged(int)));
     this->connect(m_video.data(), SIGNAL(favouriteChanged(bool)), this, SLOT(onFavouriteChanged(bool)));
@@ -287,6 +291,12 @@ void YouTubeVideoDescriptionTab::showUserChannel() {
     window->show();
 }
 
+void YouTubeVideoDescriptionTab::parseActivatedLink(const QString &link) {
+    if (!ResourceLoader::instance()->display(link, false)) {
+        QDesktopServices::openUrl(link);
+    }
+}
+
 void YouTubeVideoDescriptionTab::search(const QString &query) {
     YouTubeVideoListWindow *window = new YouTubeVideoListWindow(WindowStack::instance()->currentWindow());
     window->search(query, Settings::instance()->searchOrder(), Settings::instance()->searchTime(), Settings::instance()->searchDuration(), Settings::instance()->languageFilter());
